@@ -1,4 +1,4 @@
-from logging_helper import Locals, GLOBAL_VERBOSE, TRANSPARA_DEBUG_LEVEL, TRANSPARA_ERROR_LEVEL
+from transpara.logging_config import Locals, GLOBAL_VERBOSE, TRANSPARA_DEBUG_LEVEL, TRANSPARA_ERROR_LEVEL
 
 import os
 import sys
