@@ -1,7 +1,8 @@
 import logging
 from logging import Logger
-from logging_helper import GLOBAL_VERBOSE, TRANSPARA_DEBUG_LEVEL, TRANSPARA_ERROR_LEVEL, init_logger
-import logging_helper
+from transpara.logging_config import TRANSPARA_DEBUG_LEVEL, TRANSPARA_ERROR_LEVEL, CRITICAL_LEVEL, FATAL_LEVEL, ERROR_LEVEL, WARN_LEVEL, WARNING_LEVEL, INFO_LEVEL, DEBUG_LEVEL
+from transpara.logging_config import init_logger, RED, RESET_COLOR, BOLD_RED, BLUE, GREY, YELLOW
+from transpara import logging_config
 
 class TransparaLogger(Logger):
     
@@ -25,17 +26,16 @@ def set_log_level(level:int):
 Sets verbose exception stacks
 """
 def set_global_verbose(val:bool):
-    global GLOBAL_VERBOSE
-    GLOBAL_VERBOSE = val
+    logging_config.GLOBAL_VERBOSE = val
 
 def set_default_format(fmt:str):
-    logging_helper.default_format = fmt
+    logging_config.default_format = fmt
     init_logger()
 
 def set_tdebug_format(fmt:str):
-    logging_helper.debug_handler_format = fmt
+    logging_config.debug_handler_format = fmt
     init_logger()
 
 def set_terror_format(fmt:str):
-    logging_helper.error_handler_format = fmt 
+    logging_config.error_handler_format = fmt 
     init_logger()
